@@ -9,7 +9,7 @@ def patch_injection_provider(provider):
     such that it returns a `Mock` as the injection object.
     The injection object will be yielded by the contextmanager.
 
-    example:
+    Example::
 
         class MyService(object):
             dispatch=EventDispatcher()
